@@ -413,7 +413,7 @@ class EducLang(Base):
 
 class Group(Base):
     """
-    Группа студентов
+    Дисциплинарная группа
     """
     __tablename__ = 'univer_group'
 
@@ -425,39 +425,52 @@ class Group(Base):
         'univer_educ_plan_pos.educ_plan_pos_id'))
     educ_plan_pos = relationship('EducPlanPos', backref='groups')
 
+    # Тип обучения
+    educ_type_id = Column('educ_type_id', ForeignKey(
+        'univer_educ_type.educ_type_id'))
+    educ_type = relationship('EducType')
+
     # Преподаватель
     teacher_id = Column('teacher_id', ForeignKey('univer_teacher.teacher_id'))
     teacher = relationship('Teacher')
 
+    # Языковый отдел
+    lang_division_id = Column('lang_division_id', ForeignKey(
+        'univer_lang_division.lang_division_id'))
+    lang_division = relationship('LangDivision')
+
     # Академический год
     year = Column('group_year', Float)
 
     # Академический семестр
     semester = Column('group_semestr', Integer)
 
+    # Минимальное/Максимальное количество студентов
+    min_students = Column('group_students_min', Integer)
+    max_students = Column('group_students_max', Integer)
+
+    # Семестр повторного обучения
+    retake_semester = Column('group_retake_semestr', Integer)
+
+    # Модуль академического календаря
     acpos_module = Column('acpos_module', Integer)
 
-    educ_type_id = Column('educ_type_id', ForeignKey(
-        'univer_educ_type.educ_type_id'))
-    educ_type = relationship('EducType')
-
-    # Языковый отдел
-    lang_division_id = Column('lang_division_id', ForeignKey(
-        'univer_lang_division.lang_division_id'))
-    lang_division = relationship('LangDivision')
+    # Имя группы
+    name = Column('group_name', String(40))
 
     # Язык обучения
     educ_lang_id = Column(ForeignKey('univer_educ_lang.educ_lang_id'))
     educ_lang = relationship('EducLang')
 
-    # Семестр повторного обучения
-    retake_semester = Column('group_retake_semestr', Integer)
+    # Кафедра
+    chair_id = Column(ForeignKey('univer_chair.chair_id'))
+    chair = relationship('Chair')
 
     def __repr__(self):
         return f'<Group {self} (id={self.id} educ_plan_pos_id={self.educ_plan_pos_id} teacher_id={self.teacher_id})>'
 
     def __str__(self):
-        return f'{self.educ_plan_pos.educ_plan.speciality} ({self.educ_plan_pos.year} год)'
+        return f'{self.educ_plan_pos.educ_plan.speciality} ({self.educ_plan_pos.educ_plan.year} год)'
 
 
 class GroupStudent(Base):
